@@ -89,7 +89,7 @@ where
 
 /// A trait automatically implemented by `derive(EnumFlags)` to make the enum a valid type parameter
 /// for BitFlags.
-pub trait RawBitFlags: Copy + Clone {
+pub trait RawBitFlags: Copy + Clone + 'static {
     /// The underlying integer type.
     type Type: BitFlagNum;
 
@@ -119,6 +119,16 @@ where
     }
 }
 
+/// The default value returned is one with all flags unset, i. e. [`empty`][Self::empty].
+impl<T> Default for BitFlags<T>
+where
+    T: RawBitFlags,
+{
+    fn default() -> Self {
+        Self::empty()
+    }
+}
+
 impl<T> BitFlags<T>
 where
     T: RawBitFlags,
